@@ -3,13 +3,15 @@
 package Devel::AssertOS::DEC;
 
 use Devel::CheckOS;
+use strict;
+use warnings;
+no warnings 'redefine';
 
-$VERSION = '1.3';
+our $VERSION = '1.4';
 
-sub os_is {
-    Devel::CheckOS::os_is('OSF') ||
-    Devel::CheckOS::os_is('VMS')
-}
+sub matches { return qw(OSF VMS); }
+sub os_is { Devel::CheckOS::os_is(matches()); }
+Devel::CheckOS::die_unsupported() unless(os_is());
 
 sub expn {
 join("\n",
@@ -18,8 +20,6 @@ join("\n",
 )
 }
 
-Devel::CheckOS::die_unsupported() unless(os_is());
-
 =head1 COPYRIGHT and LICENCE
 
 Copyright 2007 - 2008 David Cantrell
